searchData={"items":[{"type":"module","title":"GettextCheck","doc":"`GettextCheck` module allows to check for missing translations\nin [gettext](https://www.gnu.org/software/gettext/) `po` and `pot` files.\n\nIt is made to work with the [elixir-gettext/gettext](https://github.com/elixir-gettext/gettext/blob/main/lib/gettext.ex)\nlibrary.","ref":"GettextCheck.html"},{"type":"module","title":"Basic Overview - GettextCheck","doc":"Using [elixir-gettext/gettext](https://github.com/elixir-gettext/gettext/blob/main/lib/gettext.ex)\non you elixir project will create a `priv/gettext`\ndirectory with the following structure:\n\n    priv/gettext\n    ├── en\n    │   └── LC_MESSAGES\n    │       └── default.po\n    └── en_US\n        └── LC_MESSAGES\n            └── default.po\n\nThese files might be missing translations under `msgstr`\n(or `msgstr[0]` and `msgstr[1]` for plural translations).\nIn a typical dev flow you would add the translations manually\nafter extracting them from your code.\n\nRuning `GettextCheck` before pushing your code to a CI/CD\npipeline can help prevent pushing mising translations to\nproduction.\n\n> This library uses [expo](https://hexdocs.pm/expo/readme.html)\ninternally to parse the `po`/`pot` files.","ref":"GettextCheck.html#module-basic-overview"},{"type":"module","title":"Usage - GettextCheck","doc":"Call `mix gettext_check` from the root of your project.\n\nAny missing translations will be listed in the output with the respective line number\n\n```bash\n      Missing translations:\n\n      msgid: 'Online'\n      /app/priv/locales/ja/LC_MESSAGES/default.po:7364\n```","ref":"GettextCheck.html#module-usage"},{"type":"module","title":"Configuration - GettextCheck","doc":"You need to specify the locale but the priv directory is optional\n(default to `priv/gettext`).\n\n`GettextCheck` can be configured in two ways:\n\n##","ref":"GettextCheck.html#module-configuration"},{"type":"module","title":"1. Command line options - GettextCheck","doc":"```bash\n  mix gettext_check --locale ja --priv priv/gettext\n```\n\n##","ref":"GettextCheck.html#module-1-command-line-options"},{"type":"module","title":"2. Mix config - GettextCheck","doc":"```elixir\n  config :gettext_check,\n    locale: \"ja\",\n    priv: \"priv/gettext\"\n```","ref":"GettextCheck.html#module-2-mix-config"},{"type":"function","title":"GettextCheck.check/1","doc":"Checks a file for missing translation and returns a list of formatted errors.","ref":"GettextCheck.html#check/1"},{"type":"function","title":"Examples - GettextCheck.check/1","doc":"iex> check(\"priv/locales/ja/LC_MESSAGES/default.po\")\n    [\n      [\"\n\", \"\u001B[0m\", \"msgid: Hello'\", \"\n\", \"\u001B[1m\", \"\u001B[31m\", \"/app/priv/locales/ja/LC_MESSAGES/default.po:12\", \"\n\"],\n      [\"\n\", \"\u001B[0m\", \"msgid: World'\", \"\n\", \"\u001B[1m\", \"\u001B[31m\", \"/app/priv/locales/ja/LC_MESSAGES/default.po:15\", \"\n\"]\n    ]","ref":"GettextCheck.html#check/1-examples"},{"type":"function","title":"GettextCheck.get_errors/2","doc":"Gets any missing translation errors from a message.","ref":"GettextCheck.html#get_errors/2"},{"type":"function","title":"Examples - GettextCheck.get_errors/2","doc":"iex> get_errors(%Message.Singular{msgid: [\"foo\"], msgstr: [\"\"]}, \"priv/locales/ja/LC_MESSAGES/default.po\")\n    [\n      [\"\n\", \"\u001B[0m\", \"msgid: foo'\", \"\n\", \"\u001B[1m\", \"\u001B[31m\", \"/app/priv/locales/ja/LC_MESSAGES/default.po:\", \"\n\"]\n    ]\n\n    iex> get_errors(%Message.Singular{msgid: [\"bar\"], msgstr: [\"bar\"]}, \"priv/locales/ja/LC_MESSAGES/default.po\")\n    []\n\n    iex> get_errors(%Message.Plural{msgid: [\"bar\"], msgid_plural: [\"bars\"], msgstr: %{0 => [\"\"], 1 => [\"\"]}}, \"priv/locales/ja/LC_MESSAGES/default.po\")\n    [\n      [\"\n\", \"\u001B[0m\", \"msgid: bars'\", \"\n\", \"\u001B[1m\", \"\u001B[31m\", \"/app/priv/locales/ja/LC_MESSAGES/default.po:\", \"\n\"],\n      [\"\n\", \"\u001B[0m\", \"msgid: bar'\", \"\n\", \"\u001B[1m\", \"\u001B[31m\", \"/app/priv/locales/ja/LC_MESSAGES/default.po:\", \"\n\"]\n    ]","ref":"GettextCheck.html#get_errors/2-examples"},{"type":"task","title":"mix gettext_check","doc":"Checks gettext translations for missing translations and raises\nan error if a translation is missing.\n\nYour files must be saved in the [gettext](https://github.com/elixir-gettext/gettext#usage) directory structure\ne.g. `priv/gettext/LOCALE/LC_MESSAGES/DOMAIN.po`\n\nGNU gettext `.pot`, `po` files are supported.\n\n```bash\nmix gettext_check [OPTIONS]\n```","ref":"Mix.Tasks.GettextCheck.html"},{"type":"task","title":"Options - mix gettext_check","doc":"* `--locale` or `-l` - the locale to check\n  * Will be used with priv to find the locale files (e.g. `{priv}/{locale}/LC_MESSAGES`)\n  * This can also be set under the config\n  * Required either here or under the config\n* `--priv` or `-p` - the path to the priv directory\n  * Defaults to `priv/gettext`\n  * This can also be set under the config","ref":"Mix.Tasks.GettextCheck.html#module-options"}],"content_type":"text/markdown"}